pub enum ForwardOperatorError<F> {
FormulaError(F),
EmptySubtraceEvaluation(Interval),
EmptyInterval,
}Expand description
Error produced during the evaluation of a forward operator.
This error represents the following error conditions while evaluating a forward operator:
- An error was encountered during the evaluation of the subformula
- The evaluation bounds for the operator resulted in a sub-trace with no elements
- The evaluation bounds for the operator create a zero-length interval
Variants