Not

Struct Not 

pub struct Not<F> { /* private fields */ }
First-order operator that inverts its subformula, written !, or not.

The Not operator is a unary operator, which means that it operates on a single subformula. This operator evaluates a given trace using its subformula, then for each time in the resulting trace negates the state. For floating point numbers, this would look as follows:

timesubformulanot
0.01.0-1.0
1.03.0-3.0
1.0-2.02.0

The following is an example of creating a formula using the not operator:

use banquo::predicate;
use banquo::operators::Not;

let subformula = predicate!{ x * 1.0 <= 1.0 };
let formula = Not::new(subformula);

Implementations

Source

impl<F> Not<F>

pub fn new(subformula: F) -> Self