pub enum BinaryOperatorError<L, R> {
LeftError(L),
RightError(R),
EvaluationError(BinaryEvaluationError),
}Expand description
Error produced during the evaluation of a binary operator.
An error can occur when evaluating a binary operator in the following circumstances:
- An error occurs during the evaluation of the left subformula
- An error occurs during the evaluation of the right subformula
- An error occurs during the application of the binary operation on the outputs of the
sub-formulas, resulting in a
BinaryEvaluationError.
Variants
LeftError(L)
An error produced by the subformula on the left of the operator
RightError(R)
An error produced by the subformula on the right of the operator
EvaluationError(BinaryEvaluationError)